# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/logging/v1/log_reading_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/logging/v1/log_reading_service.proto',
  package='yandex.cloud.logging.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;logging',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1yandex/cloud/logging/v1/log_reading_service.proto\x12\x17yandex.cloud.logging.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\"f\n\x0bReadRequest\x12\x14\n\npage_token\x18\x01 \x01(\tH\x00\x12\x35\n\x08\x63riteria\x18\x02 \x01(\x0b\x32!.yandex.cloud.logging.v1.CriteriaH\x00\x42\n\n\x08selector\"\x8e\x01\n\x0cReadResponse\x12\x14\n\x0clog_group_id\x18\x01 \x01(\t\x12\x32\n\x07\x65ntries\x18\x02 \x03(\x0b\x32!.yandex.cloud.logging.v1.LogEntry\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\x12\x1b\n\x13previous_page_token\x18\x04 \x01(\t\"\xf8\x03\n\x08\x43riteria\x12\"\n\x0clog_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=64\x12\x42\n\x0eresource_types\x18\x02 \x03(\tB*\xf2\xc7\x31\x1d|[a-zA-Z][-a-zA-Z0-9_.]{0,63}\x82\xc8\x31\x05<=100\x12\x43\n\x0cresource_ids\x18\x03 \x03(\tB-\xf2\xc7\x31 |[a-zA-Z0-9][-a-zA-Z0-9_.]{0,63}\x82\xc8\x31\x05<=100\x12)\n\x05since\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x05until\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x41\n\x06levels\x18\x06 \x03(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\x08\x82\xc8\x31\x04<=10\x12\x1a\n\x06\x66ilter\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12@\n\x0cstream_names\x18\n \x03(\tB*\xf2\xc7\x31\x1d|[a-zA-Z][-a-zA-Z0-9_.]{0,63}\x82\xc8\x31\x05<=100\x12\x1d\n\tpage_size\x18\x08 \x01(\x03\x42\n\xfa\xc7\x31\x06\x31-1000\x12)\n\x11max_response_size\x18\t \x01(\x03\x42\x0e\xfa\xc7\x31\n0-104857602h\n\x11LogReadingService\x12S\n\x04Read\x12$.yandex.cloud.logging.v1.ReadRequest\x1a%.yandex.cloud.logging.v1.ReadResponseBb\n\x1byandex.cloud.api.logging.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/logging/v1;loggingb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2.DESCRIPTOR,])




_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='yandex.cloud.logging.v1.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.logging.v1.ReadRequest.page_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='criteria', full_name='yandex.cloud.logging.v1.ReadRequest.criteria', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='selector', full_name='yandex.cloud.logging.v1.ReadRequest.selector',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=183,
  serialized_end=285,
)


_READRESPONSE = _descriptor.Descriptor(
  name='ReadResponse',
  full_name='yandex.cloud.logging.v1.ReadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.ReadResponse.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entries', full_name='yandex.cloud.logging.v1.ReadResponse.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.logging.v1.ReadResponse.next_page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous_page_token', full_name='yandex.cloud.logging.v1.ReadResponse.previous_page_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=430,
)


_CRITERIA = _descriptor.Descriptor(
  name='Criteria',
  full_name='yandex.cloud.logging.v1.Criteria',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_group_id', full_name='yandex.cloud.logging.v1.Criteria.log_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=64', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_types', full_name='yandex.cloud.logging.v1.Criteria.resource_types', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-zA-Z][-a-zA-Z0-9_.]{0,63}\202\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resource_ids', full_name='yandex.cloud.logging.v1.Criteria.resource_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-zA-Z0-9][-a-zA-Z0-9_.]{0,63}\202\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='since', full_name='yandex.cloud.logging.v1.Criteria.since', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='until', full_name='yandex.cloud.logging.v1.Criteria.until', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='levels', full_name='yandex.cloud.logging.v1.Criteria.levels', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=10', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.logging.v1.Criteria.filter', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_names', full_name='yandex.cloud.logging.v1.Criteria.stream_names', index=7,
      number=10, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\035|[a-zA-Z][-a-zA-Z0-9_.]{0,63}\202\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.logging.v1.Criteria.page_size', index=8,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0061-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_response_size', full_name='yandex.cloud.logging.v1.Criteria.max_response_size', index=9,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\n0-10485760', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=937,
)

_READREQUEST.fields_by_name['criteria'].message_type = _CRITERIA
_READREQUEST.oneofs_by_name['selector'].fields.append(
  _READREQUEST.fields_by_name['page_token'])
_READREQUEST.fields_by_name['page_token'].containing_oneof = _READREQUEST.oneofs_by_name['selector']
_READREQUEST.oneofs_by_name['selector'].fields.append(
  _READREQUEST.fields_by_name['criteria'])
_READREQUEST.fields_by_name['criteria'].containing_oneof = _READREQUEST.oneofs_by_name['selector']
_READRESPONSE.fields_by_name['entries'].message_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2._LOGENTRY
_CRITERIA.fields_by_name['since'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CRITERIA.fields_by_name['until'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CRITERIA.fields_by_name['levels'].enum_type = yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2._LOGLEVEL_LEVEL
DESCRIPTOR.message_types_by_name['ReadRequest'] = _READREQUEST
DESCRIPTOR.message_types_by_name['ReadResponse'] = _READRESPONSE
DESCRIPTOR.message_types_by_name['Criteria'] = _CRITERIA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ReadRequest = _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), {
  'DESCRIPTOR' : _READREQUEST,
  '__module__' : 'yandex.cloud.logging.v1.log_reading_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ReadRequest)
  })
_sym_db.RegisterMessage(ReadRequest)

ReadResponse = _reflection.GeneratedProtocolMessageType('ReadResponse', (_message.Message,), {
  'DESCRIPTOR' : _READRESPONSE,
  '__module__' : 'yandex.cloud.logging.v1.log_reading_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.ReadResponse)
  })
_sym_db.RegisterMessage(ReadResponse)

Criteria = _reflection.GeneratedProtocolMessageType('Criteria', (_message.Message,), {
  'DESCRIPTOR' : _CRITERIA,
  '__module__' : 'yandex.cloud.logging.v1.log_reading_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.logging.v1.Criteria)
  })
_sym_db.RegisterMessage(Criteria)


DESCRIPTOR._options = None
_CRITERIA.fields_by_name['log_group_id']._options = None
_CRITERIA.fields_by_name['resource_types']._options = None
_CRITERIA.fields_by_name['resource_ids']._options = None
_CRITERIA.fields_by_name['levels']._options = None
_CRITERIA.fields_by_name['filter']._options = None
_CRITERIA.fields_by_name['stream_names']._options = None
_CRITERIA.fields_by_name['page_size']._options = None
_CRITERIA.fields_by_name['max_response_size']._options = None

_LOGREADINGSERVICE = _descriptor.ServiceDescriptor(
  name='LogReadingService',
  full_name='yandex.cloud.logging.v1.LogReadingService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=939,
  serialized_end=1043,
  methods=[
  _descriptor.MethodDescriptor(
    name='Read',
    full_name='yandex.cloud.logging.v1.LogReadingService.Read',
    index=0,
    containing_service=None,
    input_type=_READREQUEST,
    output_type=_READRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_LOGREADINGSERVICE)

DESCRIPTOR.services_by_name['LogReadingService'] = _LOGREADINGSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto',
  package='yandex.cloud.mdb.sqlserver.v1.config',
  syntax='proto3',
  serialized_options=b'\n(yandex.cloud.api.mdb.sqlserver.v1.configZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1/config;sqlserver',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto\x12$yandex.cloud.mdb.sqlserver.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xf7\x02\n\x16SQLServerConfig2019std\x12H\n\x19max_degree_of_parallelism\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-99\x12P\n\x1e\x63ost_threshold_for_parallelism\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35-32767\x12\x39\n\x0b\x61udit_level\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-3\x12\x43\n\x13\x66ill_factor_percent\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x41\n\x1doptimize_for_ad_hoc_workloads\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x9c\x02\n\x19SQLServerConfigSet2019std\x12V\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std\x12Q\n\x0buser_config\x18\x02 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std\x12T\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std\"\xf7\x02\n\x16SQLServerConfig2019ent\x12H\n\x19max_degree_of_parallelism\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-99\x12P\n\x1e\x63ost_threshold_for_parallelism\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35-32767\x12\x39\n\x0b\x61udit_level\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-3\x12\x43\n\x13\x66ill_factor_percent\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x41\n\x1doptimize_for_ad_hoc_workloads\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x9c\x02\n\x19SQLServerConfigSet2019ent\x12V\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent\x12Q\n\x0buser_config\x18\x02 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent\x12T\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019entB~\n(yandex.cloud.api.mdb.sqlserver.v1.configZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1/config;sqlserverb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_SQLSERVERCONFIG2019STD = _descriptor.Descriptor(
  name='SQLServerConfig2019std',
  full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_degree_of_parallelism', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std.max_degree_of_parallelism', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0041-99', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost_threshold_for_parallelism', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std.cost_threshold_for_parallelism', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0075-32767', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audit_level', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std.audit_level', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0030-3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fill_factor_percent', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std.fill_factor_percent', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimize_for_ad_hoc_workloads', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std.optimize_for_ad_hoc_workloads', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=537,
)


_SQLSERVERCONFIGSET2019STD = _descriptor.Descriptor(
  name='SQLServerConfigSet2019std',
  full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019std',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019std.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019std.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019std.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=540,
  serialized_end=824,
)


_SQLSERVERCONFIG2019ENT = _descriptor.Descriptor(
  name='SQLServerConfig2019ent',
  full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_degree_of_parallelism', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent.max_degree_of_parallelism', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0041-99', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost_threshold_for_parallelism', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent.cost_threshold_for_parallelism', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0075-32767', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audit_level', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent.audit_level', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0030-3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fill_factor_percent', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent.fill_factor_percent', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0050-100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='optimize_for_ad_hoc_workloads', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent.optimize_for_ad_hoc_workloads', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=827,
  serialized_end=1202,
)


_SQLSERVERCONFIGSET2019ENT = _descriptor.Descriptor(
  name='SQLServerConfigSet2019ent',
  full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019ent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019ent.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019ent.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019ent.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1489,
)

_SQLSERVERCONFIG2019STD.fields_by_name['max_degree_of_parallelism'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019STD.fields_by_name['cost_threshold_for_parallelism'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019STD.fields_by_name['audit_level'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019STD.fields_by_name['fill_factor_percent'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019STD.fields_by_name['optimize_for_ad_hoc_workloads'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SQLSERVERCONFIGSET2019STD.fields_by_name['effective_config'].message_type = _SQLSERVERCONFIG2019STD
_SQLSERVERCONFIGSET2019STD.fields_by_name['user_config'].message_type = _SQLSERVERCONFIG2019STD
_SQLSERVERCONFIGSET2019STD.fields_by_name['default_config'].message_type = _SQLSERVERCONFIG2019STD
_SQLSERVERCONFIG2019ENT.fields_by_name['max_degree_of_parallelism'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019ENT.fields_by_name['cost_threshold_for_parallelism'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019ENT.fields_by_name['audit_level'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019ENT.fields_by_name['fill_factor_percent'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SQLSERVERCONFIG2019ENT.fields_by_name['optimize_for_ad_hoc_workloads'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_SQLSERVERCONFIGSET2019ENT.fields_by_name['effective_config'].message_type = _SQLSERVERCONFIG2019ENT
_SQLSERVERCONFIGSET2019ENT.fields_by_name['user_config'].message_type = _SQLSERVERCONFIG2019ENT
_SQLSERVERCONFIGSET2019ENT.fields_by_name['default_config'].message_type = _SQLSERVERCONFIG2019ENT
DESCRIPTOR.message_types_by_name['SQLServerConfig2019std'] = _SQLSERVERCONFIG2019STD
DESCRIPTOR.message_types_by_name['SQLServerConfigSet2019std'] = _SQLSERVERCONFIGSET2019STD
DESCRIPTOR.message_types_by_name['SQLServerConfig2019ent'] = _SQLSERVERCONFIG2019ENT
DESCRIPTOR.message_types_by_name['SQLServerConfigSet2019ent'] = _SQLSERVERCONFIGSET2019ENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SQLServerConfig2019std = _reflection.GeneratedProtocolMessageType('SQLServerConfig2019std', (_message.Message,), {
  'DESCRIPTOR' : _SQLSERVERCONFIG2019STD,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std)
  })
_sym_db.RegisterMessage(SQLServerConfig2019std)

SQLServerConfigSet2019std = _reflection.GeneratedProtocolMessageType('SQLServerConfigSet2019std', (_message.Message,), {
  'DESCRIPTOR' : _SQLSERVERCONFIGSET2019STD,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019std)
  })
_sym_db.RegisterMessage(SQLServerConfigSet2019std)

SQLServerConfig2019ent = _reflection.GeneratedProtocolMessageType('SQLServerConfig2019ent', (_message.Message,), {
  'DESCRIPTOR' : _SQLSERVERCONFIG2019ENT,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent)
  })
_sym_db.RegisterMessage(SQLServerConfig2019ent)

SQLServerConfigSet2019ent = _reflection.GeneratedProtocolMessageType('SQLServerConfigSet2019ent', (_message.Message,), {
  'DESCRIPTOR' : _SQLSERVERCONFIGSET2019ENT,
  '__module__' : 'yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfigSet2019ent)
  })
_sym_db.RegisterMessage(SQLServerConfigSet2019ent)


DESCRIPTOR._options = None
_SQLSERVERCONFIG2019STD.fields_by_name['max_degree_of_parallelism']._options = None
_SQLSERVERCONFIG2019STD.fields_by_name['cost_threshold_for_parallelism']._options = None
_SQLSERVERCONFIG2019STD.fields_by_name['audit_level']._options = None
_SQLSERVERCONFIG2019STD.fields_by_name['fill_factor_percent']._options = None
_SQLSERVERCONFIG2019ENT.fields_by_name['max_degree_of_parallelism']._options = None
_SQLSERVERCONFIG2019ENT.fields_by_name['cost_threshold_for_parallelism']._options = None
_SQLSERVERCONFIG2019ENT.fields_by_name['audit_level']._options = None
_SQLSERVERCONFIG2019ENT.fields_by_name['fill_factor_percent']._options = None
# @@protoc_insertion_point(module_scope)
